#!/usr/bin/env python3
"""Validation script for main refactoring."""

import sys
import os

# Add parent directory to path to import utils
sys.path.insert(0, os.path.dirname(os.path.abspath(__file__)))

from utils.validation_common import (
    validate_jsx_component,
    count_complexity,
    print_validation_header,
    print_complexity_analysis,
    print_summary_footer,
    run_validation,
)

def main():
    """Validate main refactoring."""
    # Components to validate
    components = {
        'TicketsPanelRefactored.jsx': ['TicketsPanelRefactored'],
        'TicketFilters.jsx': ['TicketFilters'],
        'BulkOperations.jsx': ['BulkOperations'],
        'TicketList.jsx': ['TicketList'],
        'TicketStats.jsx': ['TicketStats']
    }
    
    base_path = 'src/proxym/dashboard/components/tickets'
    original_file = 'src/proxym/dashboard/components/tickets.jsx'
    
    benefits_text = """  ✅ Separated ticket management into focused components
  ✅ Improved reusability of ticket logic
  ✅ Enhanced testability with isolated components
  ✅ Better maintainability through modular design"""
    
    return run_validation(
        title="Main Refactoring",
        components=components,
        base_path=base_path,
        original_file=original_file,
        benefits_text=benefits_text
    )

if __name__ == "__main__":
    main()



#!/usr/bin/env python3
"""Validation script for TasksPanel refactoring."""

import sys
import os

# Add parent directory to path to import utils
sys.path.insert(0, os.path.dirname(os.path.abspath(__file__)))

from utils.validation_common import (
    validate_jsx_component,
    count_complexity,
    print_validation_header,
    print_complexity_analysis,
    print_summary_footer,
    run_validation,
    run_validation_main,
)


def main():
    """Validate TasksPanel refactoring."""
    return run_validation_main(
        title="TasksPanel Refactoring",
        components={
            'TasksViewControls.jsx': ['TasksViewControls'],
            'TasksBoard.jsx': ['TasksBoard'],
            'TasksList.jsx': ['TasksList'],
            'TasksTable.jsx': ['TasksTable'],
            'TasksRecentJobs.jsx': ['TasksRecentJobs'],
            'TasksPanelRefactored.jsx': ['TasksPanelRefactored']
        },
        base_path='src/proxym/dashboard/components/tasks',
        original_file='src/proxym/dashboard/components/tasks.jsx',
        benefits_bullet='task management'
    )

if __name__ == "__main__":
    main()



#!/usr/bin/env python3
"""Validation script for HumanTaskPanel refactoring."""

import sys
import os

# Add parent directory to path to import utils
sys.path.insert(0, os.path.dirname(os.path.abspath(__file__)))

from utils.validation_common import (
    validate_jsx_component,
    count_complexity,
    print_validation_header,
    print_complexity_analysis,
    print_summary_footer,
    run_validation,
    run_validation_main,
)


def main():
    """Validate HumanTaskPanel refactoring."""
    return run_validation_main(
        title="HumanTaskPanel Refactoring",
        components={
            'HumanTaskStats.jsx': ['HumanTaskStats'],
            'HumanTaskBoard.jsx': ['HumanTaskBoard'],
            'HumanTaskList.jsx': ['HumanTaskList'],
            'HumanJobsList.jsx': ['HumanJobsList'],
            'HumanViewControls.jsx': ['HumanViewControls'],
            'HumanTaskPanelRefactored.jsx': ['HumanTaskPanelRefactored']
        },
        base_path='src/proxym/dashboard/components/human',
        original_file='src/proxym/dashboard/components/human.jsx',
        benefits_bullet='human task management'
    )

if __name__ == "__main__":
    main()



#!/usr/bin/env python3
"""Validation script for TicketDispatchTable refactoring."""

import sys
import os

# Add parent directory to path to import utils
sys.path.insert(0, os.path.dirname(os.path.abspath(__file__)))

from utils.validation_common import (
    validate_jsx_component,
    count_complexity,
    print_validation_header,
    print_complexity_analysis,
    print_summary_footer,
    run_validation,
    run_validation_main,
)


def main():
    """Validate TicketDispatchTable refactoring."""
    return run_validation_main(
        title="TicketDispatchTable Refactoring",
        components={
            'DispatchTableHeader.jsx': ['DispatchTableHeader'],
            'DispatchTableRow.jsx': ['DispatchTableRow'],
            'TicketStatusBadges.jsx': ['TicketStatusBadges'],
            'ProjectInfoResolver.jsx': ['ProjectInfoResolver'],
            'DispatchActions.jsx': ['DispatchActions'],
            'TicketDispatchTableRefactored.jsx': ['TicketDispatchTableRefactored']
        },
        base_path='src/proxym/dashboard/components/tools',
        original_file='src/proxym/dashboard/components/tools.jsx',
        benefits_bullet='dispatch logic'
    )

if __name__ == "__main__":
    main()



#!/usr/bin/env python3
"""Validation script for ToolHealth refactoring."""

import sys
import os

# Add parent directory to path to import utils
sys.path.insert(0, os.path.dirname(os.path.abspath(__file__)))

from utils.validation_common import (
    validate_jsx_component,
    count_complexity,
    print_validation_header,
    print_complexity_analysis,
    print_summary_footer,
    run_validation,
    run_validation_main,
)


def main():
    """Validate ToolHealth refactoring."""
    return run_validation_main(
        title="ToolHealth Refactoring",
        components={
            'ToolHealthCard.jsx': ['ToolHealthCard'],
            'ToolHealthDisplay.jsx': ['ToolHealthDisplay'],
            'ToolHealthPanelRefactored.jsx': ['ToolHealthPanelRefactored'],
            'ToolAvailabilityAlert.jsx': ['ToolAvailabilityAlert'],
            'BulkAutoFix.jsx': ['BulkAutoFix'],
            'DiagnosticActions.jsx': ['DiagnosticActions']
        },
        base_path='src/proxym/dashboard/components/tools',
        original_file='src/proxym/dashboard/components/tools.jsx',
        benefits_bullet='health monitoring'
    )

if __name__ == "__main__":
    main()



#!/usr/bin/env python3
"""Validation script for ToolsPanel refactoring."""

import sys
import os

# Add parent directory to path to import utils
sys.path.insert(0, os.path.dirname(os.path.abspath(__file__)))

from utils.validation_common import (
    validate_jsx_component,
    count_complexity,
    print_validation_header,
    print_complexity_analysis,
    print_summary_footer,
    run_validation,
)


def main():
    """Validate ToolsPanel refactoring."""
    # Components to validate
    components = {
        'ToolsRegistry.jsx': ['ToolsRegistry'],
        'ToolsJobQueue.jsx': ['ToolsJobQueue'],
        'ToolsDispatch.jsx': ['ToolsDispatch'],
        'ToolsPanelRefactored.jsx': ['ToolsPanelRefactored']
    }
    
    base_path = 'src/proxym/dashboard/components/tools'
    original_file = 'src/proxym/dashboard/components/tools.jsx'
    
    benefits_text = """  ✅ Separated concerns into focused components
  ✅ Improved reusability of tool management logic
  ✅ Enhanced testability with isolated components
  ✅ Better maintainability through modular design"""
    
    return run_validation(
        title="ToolsPanel Refactoring",
        components=components,
        base_path=base_path,
        original_file=original_file,
        benefits_text=benefits_text
    )

if __name__ == "__main__":
    main()
